==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/ro.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Activități",
    "Error loading activities" : "Eroare la încărcarea activităților",
    "No activities" : "Fără activități",
    "Load more activities" : "Încarcă mai multe activități",
    "This stream will show events like additions, changes & shares" : "Acest flux va afișa evenimente ca adăugiri, modificări & partajări",
    "There are no events for this filter" : "Nu sunt evenimente pentru acest filtru",
    "Today" : "Astăzi",
    "Yesterday" : "Ieri",
    "Activity" : "Activitate",
    "Personal activity feed for %s" : "Activitate recentă personală pentru %s",
    "Your feed URL is invalid" : "Adresa URL a fluxului e invalidă",
    "Your settings have been updated." : "Setările au fost actualizate.",
    "Mail" : "Mail",
    "Stream" : "Flux",
    "\"remote user\"" : "\"utilizator la distanță\"",
    "Activity notification" : "Notificări de activitate",
    ", " : ",",
    "%s and %s" : "%s și %s",
    "Hello %s," : "Salut %s,",
    "You are receiving this email because the following things happened at %s" : "Primești acest email deoarece următoarele evenimente s-au petrecut la %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* și %n altele","* și %n altele","* și %n altele"],
    "Notify about your own actions via email" : "Notificări pentru activitățile tale prin email",
    "You need to set up your email address before you can receive notification emails." : "Trebuie să-ți configurezi adresa de email înainte de a putea primi emailurile de notificare.",
    "Send emails:" : "Trimite email-uri:",
    "Hourly" : "În fiecare oră",
    "Daily" : "Zilnic",
    "Weekly" : "Săptămânal",
    "Activity feed" : "Flux de activitate",
    "Enable RSS feed" : "Activați feed RSS",
    "No activity yet" : "Nici o activitate încă.",
    "No more events to load" : "Nu mai sunt evenimente de încărcat",
    "Files" : "Fișiere"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/ro.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Activități",
    "An error occurred while loading activities" : "A apărut o eroare la încărcarea activităților",
    "No activity yet" : "Nici o activitate încă.",
    "Load more activities" : "Încarcă mai multe activități",
    "Copied!" : "S-a copiat!",
    "Not supported!" : "Nu este suportat!",
    "Press ⌘-C to copy." : "Apasă ⌘-C pentru a copia.",
    "Press Ctrl-C to copy." : "Apasă Ctrl-C pentru a copia.",
    "{name} (invisible)" : "{name} (invizibil)",
    "{name} (restricted)" : "{name} (restricționat)",
    "in {path}" : "în {path}",
    "This stream will show events like additions, changes & shares" : "Acest flux va afișa evenimente ca adăugiri, modificări & partajări",
    "There are no events for this filter" : "Nu sunt evenimente pentru acest filtru",
    "Today" : "Astăzi",
    "Yesterday" : "Ieri",
    "Personal activity feed for %s" : "Activitate recentă personală pentru %s",
    "Your feed URL is invalid" : "Adresa URL a fluxului e invalidă",
    "Your settings have been updated." : "Setările au fost actualizate.",
    "Settings have been updated." : "Setările au fost actualizate.",
    "Mail" : "Mail",
    "Stream" : "Flux",
    "All activities" : "Toate activitățile",
    "By others" : "De către alții",
    "By you" : "De către tine",
    "\"remote user\"" : "\"utilizator la distanță\"",
    "Hello %s," : "Salut %s,",
    "There was some activity at %s" : "A fost activitate la %s",
    "Activity notification" : "Notificări de activitate",
    ", " : ",",
    "%s and %s" : "%s și %s",
    "Activity" : "Activitate",
    "Activity feed" : "Flux de activitate",
    "List your own actions in the stream" : "Afișează propriile tale acțiuni în flux",
    "Notify about your own actions via email" : "Notificări pentru activitățile tale prin email",
    "You need to set up your email address before you can receive notification emails." : "Trebuie să-ți configurezi adresa de email înainte de a putea primi emailurile de notificare.",
    "Send emails:" : "Trimite email-uri:",
    "Hourly" : "În fiecare oră",
    "Daily" : "Zilnic",
    "Weekly" : "Săptămânal",
    "Settings" : "Setări",
    "Enable RSS feed" : "Activați feed RSS",
    "No more events to load" : "Nu mai sunt evenimente de încărcat",
    "Files" : "Fișiere"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
